<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Run command</source>
        <translation>Executar comando</translation>
    </message>
</context>
</TS>